@@ -1,7 +1,7 @@
 import os
 
 from pathlib import Path
-from pytest import fixture, hookimpl, mark
+from pytest import fixture, mark
 
 from wand.version import MAGICK_VERSION, VERSION
 
@@ -50,23 +50,6 @@ def pytest_configure(config):
     )
 
 
-@hookimpl(tryfirst=True, hookwrapper=True)
-def pytest_runtest_makereport(item, call):
-    """Copied from
-    http://pytest.org/dev/example/simple.html
-    #making-test-result-information-available-in-fixtures
-
-    """  # noqa
-    # execute all other hooks to obtain the report object
-    outcome = yield
-    rep = outcome.get_result()
-
-    # set a report attribute for each phase of a call, which can
-    # be "setup", "call", "teardown"
-
-    setattr(item, "rep_" + rep.when, rep)
-
-
 def pytest_report_header(config):
     versions = (VERSION, os.linesep, MAGICK_VERSION)
     return "Wand Version: {0}{1}ImageMagick Version: {2}".format(*versions)
