@@ -61,10 +61,12 @@ def test_set_get_clip_units():
             ctx.clip_units = 'not-a-clip_unit'
 
 
-def test_set_get_font(fx_asset):
+def test_set_get_font():
     with Drawing() as ctx:
-        ctx.font = str(fx_asset.join('League_Gothic.otf'))
-        assert ctx.font == str(fx_asset.join('League_Gothic.otf'))
+        """Setting this values doesn't actually check if the typeface file
+        exists, but the get/set values should still agree."""
+        ctx.font = 'GhostType.ttf'
+        assert ctx.font == 'GhostType.ttf'
         with raises(TypeError):
             ctx.font = 0xDEADBEEF
 
@@ -292,7 +294,7 @@ def test_draw_arc():
         assert was != img.signature
 
 
-def test_draw_circle(fx_asset):
+def test_draw_circle():
     with Image(width=50, height=50, background='white') as img:
         was = img.signature
         with Drawing() as ctx:
@@ -422,17 +424,14 @@ def test_draw_polygon():
 
 
 def test_draw_polyline():
-    white = Color('WHITE')
-    red = Color('RED')
-    blue = Color('BLUE')
-    with Image(width=50, height=50, background=white) as img:
+    with Image(width=50, height=50, background='white') as img:
+        was = img.signature
         with Drawing() as draw:
-            draw.fill_color = blue
-            draw.stroke_color = red
+            draw.fill_color = 'blue'
+            draw.stroke_color = 'red'
             draw.polyline([(10, 10), (40, 25), (10, 40)])
             draw.draw(img)
-            assert img[10, 25] == img[25, 25] == blue
-            assert img[35, 15] == img[35, 35] == white
+        assert was != img.signature
 
 
 def test_draw_push_pop():
@@ -734,7 +733,7 @@ def test_draw_text(fx_asset):
     with Image(width=100, height=100, background='white') as img:
         was = img.signature
         with Drawing() as ctx:
-            ctx.font = str(fx_asset.join('League_Gothic.otf'))
+            ctx.font = str(fx_asset.joinpath('League_Gothic.otf'))
             ctx.font_size = 25
             ctx.fill_color = 'black'
             ctx.gravity = 'west'
@@ -743,10 +742,10 @@ def test_draw_text(fx_asset):
         assert was != img.signature
 
 
-def test_get_font_metrics_test(fx_asset):
+def test_get_font_metrics(fx_asset):
     with Image(width=144, height=192, background=Color('#fff')) as img:
         with Drawing() as draw:
-            draw.font = str(fx_asset.join('League_Gothic.otf'))
+            draw.font = str(fx_asset.joinpath('League_Gothic.otf'))
             draw.font_size = 13
             nm1 = draw.get_font_metrics(img, 'asdf1234')
             nm2 = draw.get_font_metrics(img, 'asdf1234asdf1234')
@@ -764,7 +763,7 @@ def test_get_font_metrics_test(fx_asset):
             assert m2.text_height < m3.text_height
 
 
-def test_viewbox(fx_asset):
+def test_viewbox():
     with Drawing() as draw:
         with raises(TypeError):
             draw.viewbox(None, None, None, None)
@@ -777,7 +776,7 @@ def test_viewbox(fx_asset):
         draw.viewbox(10, 10, 100, 100)
 
 
-def test_regression_issue_163(tmpdir):
+def test_regression_issue_163(tmp_path):
     """https://github.com/emcconville/wand/issues/163"""
     unicode_char = b'\xce\xa6'.decode('utf-8')
     with Drawing() as draw:
@@ -786,7 +785,7 @@ def test_regression_issue_163(tmpdir):
             draw.gravity = 'south_west'
             draw.text(0, 0, unicode_char)
             draw(image)
-            image.save(filename=str(tmpdir.join('out.jpg')))
+            image.save(filename=str(tmp_path / 'out.jpg'))
 
 
 def test_set_get_fill_opacity():
